@@ -5,7 +5,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Pod::Simple::Wiki);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 ###############################################################################
 #
@@ -18,8 +18,8 @@ my $tags = {
             '</i>'   => '_',
             '<tt>'   => '`',
             '</tt>'  => '`',
-            '<pre>'  => '{{{',
-            '</pre>' => "}}}\n\n",
+            '<pre>'  => "{{{\n",
+            '</pre>' => "\n}}}\n\n",
 
             '<h1>'   => "\n----\n= ",
             '</h1>'  => " =\n\n",
